import { DateComponent, ViewProps, Hit, DateRange, DateMarker, DateProfile, DateEnv, BaseOptionsRefined, DateProfileGenerator, Seg, Slicer, EventStore, EventUiHash, DateSpan, EventInteractionState, BaseComponent, SegGroup, SegSpan } from '@fullcalendar/core/internal';
import { createElement, Ref } from '@fullcalendar/core/preact';
import { Duration, CssDimValue } from '@fullcalendar/core';

interface TimelineViewState {
    scrollerWidth?: number;
    leftScrollbarWidth?: number;
    rightScrollbarWidth?: number;
    slotInnerWidth?: number;
}
declare class TimelineView extends DateComponent<ViewProps, TimelineViewState> {
    private buildTimelineDateProfile;
    private computeSlotWidth;
    private headerScrollerRef;
    private bodyScrollerRef;
    private footerScrollerRef;
    private tDateProfile?;
    private bodyEl?;
    private slotWidth?;
    private headerRowInnerWidthMap;
    private bodySlotInnerWidth?;
    private syncedScroller;
    private scrollTime;
    render(): createElement.JSX.Element;
    componentDidMount(): void;
    componentDidUpdate(prevProps: ViewProps): void;
    componentWillUnmount(): void;
    handleBodySlotInnerWidth: (innerWidth: number) => void;
    handleSlotInnerWidths: () => void;
    handleScrollerWidth: (scrollerWidth: number) => void;
    handleLeftScrollbarWidth: (leftScrollbarWidth: number) => void;
    handleRightScrollbarWidth: (rightScrollbarWidth: number) => void;
    private updateSyncedScroller;
    private resetScroll;
    private handleTimeScroll;
    private updateScroll;
    private clearScroll;
    handeBodyEl: (el: HTMLElement | null) => void;
    queryHit(positionLeft: number, positionTop: number, elWidth: number, elHeight: number): Hit;
}

interface TimelineDateProfile {
    labelInterval: Duration;
    slotDuration: Duration;
    slotsPerLabel: number;
    headerFormats: any;
    isTimeScale: boolean;
    largeUnit: string;
    emphasizeWeeks: boolean;
    snapDuration: Duration;
    snapsPerSlot: number;
    normalizedRange: DateRange;
    timeWindowMs: number;
    slotDates: DateMarker[];
    isWeekStarts: boolean[];
    snapDiffToIndex: number[];
    snapIndexToDiff: number[];
    snapCnt: number;
    slotCnt: number;
    cellRows: TimelineHeaderCellData[][];
}
interface TimelineHeaderCellData {
    date: DateMarker;
    text: string;
    rowUnit: string;
    colspan: number;
    isWeekStart: boolean;
}
declare function buildTimelineDateProfile(dateProfile: DateProfile, dateEnv: DateEnv, allOptions: BaseOptionsRefined, dateProfileGenerator: DateProfileGenerator): TimelineDateProfile;

interface TimelineLaneSeg extends Seg {
    start: DateMarker;
    end: DateMarker;
}
declare class TimelineLaneSlicer extends Slicer<TimelineLaneSeg, [
    DateProfile,
    DateProfileGenerator,
    TimelineDateProfile,
    DateEnv
]> {
    sliceRange(origRange: DateRange, dateProfile: DateProfile, dateProfileGenerator: DateProfileGenerator, tDateProfile: TimelineDateProfile, dateEnv: DateEnv): TimelineLaneSeg[];
}

interface TimelineSegHorizontals {
    start: number;
    size: number;
}

interface TimelineLaneProps {
    dateProfile: DateProfile;
    tDateProfile: TimelineDateProfile;
    nowDate: DateMarker;
    todayRange: DateRange;
    nextDayThreshold: Duration;
    eventStore: EventStore | null;
    eventUiBases: EventUiHash;
    businessHours: EventStore | null;
    dateSelection: DateSpan | null;
    eventDrag: EventInteractionState | null;
    eventResize: EventInteractionState | null;
    eventSelection: string;
    resourceId?: string;
    slotWidth: number | undefined;
}
interface TimelineLaneState {
    segHeightRev?: string;
    moreLinkHeightRev?: string;
}
declare class TimelineLane extends BaseComponent<TimelineLaneProps, TimelineLaneState> {
    private sortEventSegs;
    private segHeightRefMap;
    private moreLinkHeightRefMap;
    private slicer;
    render(): createElement.JSX.Element;
    renderFgSegs(segs: TimelineLaneSeg[], segHorizontals: {
        [instanceId: string]: TimelineSegHorizontals;
    }, segTops: {
        [instanceId: string]: number;
    }, forcedInvisibleMap: {
        [instanceId: string]: any;
    }, hiddenGroups: SegGroup[], hiddenGroupTops: {
        [key: string]: number;
    }, isDragging: boolean, isResizing: boolean, isDateSelecting: boolean): createElement.JSX.Element;
    private handleMoreLinkHeights;
    private handleSegHeights;
}

interface TimelineLaneBgProps {
    tDateProfile: TimelineDateProfile;
    nowDate: DateMarker;
    todayRange: DateRange;
    bgEventSegs: TimelineLaneSeg[] | null;
    businessHourSegs: TimelineLaneSeg[] | null;
    dateSelectionSegs: TimelineLaneSeg[];
    eventResizeSegs: TimelineLaneSeg[];
    slotWidth: number | undefined;
}
declare class TimelineLaneBg extends BaseComponent<TimelineLaneBgProps> {
    render(): createElement.JSX.Element;
    renderSegs(segs: TimelineLaneSeg[], fillType: string): createElement.JSX.Element;
}

interface TimelineSlatsProps {
    dateProfile: DateProfile;
    tDateProfile: TimelineDateProfile;
    nowDate: DateMarker;
    todayRange: DateRange;
    slotWidth: number | undefined;
    innerWidthRef?: Ref<number>;
}
declare class TimelineSlats extends BaseComponent<TimelineSlatsProps> {
    private innerWidthRefMap;
    render(): createElement.JSX.Element;
    handleInnerWidths: () => void;
}

interface CoordRange {
    start: number;
    size: number;
}
declare function createVerticalStyle(props: {
    start: number;
    size: number;
} | undefined): {
    top: number;
    height: number;
} | undefined;
declare function createHorizontalStyle(props: {
    start: number;
    size: number;
} | undefined, isRtl: boolean): {
    left: number;
    width: number;
} | {
    right: number;
    width: number;
} | undefined;
declare function computeSlotWidth(slatCnt: number, slatsPerLabel: number, slatMinWidth: number | undefined, labelInnerWidth: number | undefined, viewportWidth: number | undefined): [
    canvasWidth: number | undefined,
    slatWidth: number | undefined,
    slatLiquid: boolean
];
declare function timeToCoord(// pixels
time: Duration, dateEnv: DateEnv, dateProfile: DateProfile, tDateProfile: TimelineDateProfile, slowWidth: number): number;

declare function coordToCss(hcoord: number | null, isRtl: boolean): {
    left: CssDimValue;
    right: CssDimValue;
};
declare function coordsToCss(hcoords: SegSpan | null, isRtl: boolean): {
    left: CssDimValue;
    right: CssDimValue;
};

interface TimelineHeaderRowProps {
    dateProfile: DateProfile;
    tDateProfile: TimelineDateProfile;
    nowDate: DateMarker;
    todayRange: DateRange;
    rowLevel: number;
    isLastRow: boolean;
    cells: TimelineHeaderCellData[];
    innerHeighRef?: Ref<number>;
    innerWidthRef?: Ref<number>;
    slotWidth: number | undefined;
    height?: number;
}
declare class TimelineHeaderRow extends BaseComponent<TimelineHeaderRowProps> {
    private innerWidthRefMap;
    private innerHeightRefMap;
    render(): createElement.JSX.Element;
    handleInnerWidths: () => void;
    handleInnerHeights: () => void;
    componentWillUnmount(): void;
}

interface TimelineNowIndicatorArrowProps {
    tDateProfile: TimelineDateProfile;
    nowDate: DateMarker;
    slotWidth: number | undefined;
}
declare class TimelineNowIndicatorArrow extends BaseComponent<TimelineNowIndicatorArrowProps> {
    render(): createElement.JSX.Element;
}

interface TimelineNowIndicatorLineProps {
    tDateProfile: TimelineDateProfile;
    nowDate: DateMarker;
    slotWidth: number | undefined;
}
declare class TimelineNowIndicatorLine extends BaseComponent<TimelineNowIndicatorLineProps> {
    render(): createElement.JSX.Element;
}

export { CoordRange, TimelineDateProfile, TimelineHeaderRow, TimelineLane, TimelineLaneBg, TimelineLaneProps, TimelineLaneSeg, TimelineLaneSlicer, TimelineNowIndicatorArrow, TimelineNowIndicatorLine, TimelineSlats, TimelineView, buildTimelineDateProfile, computeSlotWidth, coordToCss, coordsToCss, createHorizontalStyle, createVerticalStyle, timeToCoord };
